
# TinySim 

[![PyPI](https://img.shields.io/pypi/v/coderbot-sim.svg)](https://pypi.org/project/coderbot-sim)
[![Jupyterlite](https://jupyterlite.rtfd.io/en/latest/_static/badge.svg)](https://matthewandretaylor.github.io/CoderBots/lab?path=example.ipynb)

The goal of this project is to create more minimal simulation environments for robotics and machine learning.

Existing solutions like [ROS 2](https://github.com/ros2) and [Gymnasium](https://gymnasium.farama.org/) come with many heavy dependencies.

Additionally they are usually difficult to get setup and may require domain specific knowledge to use.
Simulation environments should be able to run in any notebook environment and require fewer dependencies.


## Get Started 🚀

To use the baseline Python only simulation environments.

```bash
pip install tinysim
```

To use the [warp](https://github.com/NVIDIA/warp) simulation environments.

```bash
pip install tinysim[warp]
```



